/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxPersistenceUnit.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.api;

import javax.annotation.Resource.AuthenticationType;

/**
 * Manages Resource annotation.
 * @author Florent BENOIT
 */
public interface IJAnnotationResource {

    /**
     * @return Name (resource to be looked up).
     */
    String getName();

    /**
     * Sets Name (resource to be looked up).
     * @param name the given name.
     */
    void setName(final String name);

    /**
     * @return the authentication type.
     */
    AuthenticationType getAuthenticationType();

    /**
     * Sets the authentication type.
     * @param authenticationType value to set.
     */
    void setAuthenticationType(final AuthenticationType authenticationType);

    /**
     * @return the description.
     */
    String getDescription();

    /**
     * Sets the description.
     * @param description value to set.
     */
    void setDescription(final String description);

    /**
     * @return true if it is shareable.
     */
    boolean isShareable();

    /**
     * Sets the shareable attribute (false/true).
     * @param shareable a boolean.
     */
    void setShareable(final boolean shareable);

    /**
     * @return the type of resource (class).
     */
    String getType();

    /**
     * Sets the class type of this object.
     * @param type the class value (as string format).
     */
    void setType(final String type);

    /**
     * @return MappedName.
     */
    String getMappedName();

    /**
     * Sets mapped Name.
     * @param mappedName the given mappedName.
     */
    void setMappedName(final String mappedName);
}
