/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ClientEnhancer.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.client;

import java.util.List;
import java.util.Map;

import org.ow2.easybeans.asm.ClassReader;
import org.ow2.easybeans.asm.ClassWriter;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarArchiveMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;
import org.ow2.easybeans.enhancer.Enhancer;
import org.ow2.easybeans.enhancer.EnhancerException;
import org.ow2.easybeans.enhancer.client.ClientLifeCycleAdapter;
import org.ow2.easybeans.enhancer.injection.InjectionClassAdapter;
import org.ow2.easybeans.loader.EasyBeansClassLoader;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * /**
 * This enhancer is used by the client container to enhance client classes.
 * For example, it will allow to use &#64;EJB annotations, etc.
 * @author Florent Benoit
 */
public class ClientEnhancer extends Enhancer {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(ClientEnhancer.class);

    /**
     * Creates an new enhancer.
     * @param loader classloader where to define enhanced classes.
     * @param ejbJarAnnotationMetadata object with references to the metadata.
     * @param map a map allowing to give some objects to the enhancer.
     */
    public ClientEnhancer(final ClassLoader loader, final EjbJarArchiveMetadata ejbJarAnnotationMetadata,
            final Map<String, Object> map) {
        super(loader, ejbJarAnnotationMetadata, map);
    }

    /**
     * Allow to enhance a given set of classes.
     * @param loader the classloader that will be used to load the classes.
     * @param classesToEnhance the set of classes to enhance
     * @param map a map allowing to give some objects to the enhancer.
     * @throws  EnhancerException if enhancer fails
     */
    public static void enhance(final ClassLoader loader, final List<String> classesToEnhance,
            final Map<String, Object> map) throws EnhancerException {
        EjbJarArchiveMetadata ejbJarAnnotationMetadata = new EjbJarArchiveMetadata();
        // FIXME ScanClassVisitor scanVisitor = new ScanClassVisitor(ejbJarAnnotationMetadata);
        logger.info("ClassLoader used = {0}", loader);
        for (String clazz : classesToEnhance) {
        // FIXME    read(clazz, loader, scanVisitor, ejbJarAnnotationMetadata);
        }

        ClientEnhancer clientEnhancer = new ClientEnhancer(loader, ejbJarAnnotationMetadata, map);
        clientEnhancer.enhance();
    }


    /**
     * Visits the given class and all available parent classes.
     * @param className the class to visit.
     * @param loader the classloader to use.
     * @param scanVisitor the ASM visitor.
     * @param ejbJarAnnotationMetadata the structure containing class metadata
     * @throws EnhancerException if class can't be analyzed.
     */
    /*
    private static void read(final String className, final ClassLoader loader, final ScanClassVisitor scanVisitor,
            final EjbJarAnnotationMetadata ejbJarAnnotationMetadata) throws EnhancerException {
        String readingClass = className;
        if (!className.toLowerCase().endsWith(".class")) {
            readingClass = className + ".class";
        }

        InputStream is = loader.getResourceAsStream(readingClass);

        logger.info("Visiting class {0}", className);
        try {
            new ClassReader(is).accept(scanVisitor, 0);
        } catch (IOException e) {
            throw new EnhancerException("Cannot read the given class '" + className + "'.", e);
        }

        // get the class parsed
        EjbJarClassMetadata classMetadata = ejbJarAnnotationMetadata.getClassAnnotationMetadata(className);
        String superClassName = classMetadata.getSuperName();
        if (!superClassName.equals(JAVA_LANG_OBJECT)) {
            read(superClassName, loader, scanVisitor, ejbJarAnnotationMetadata);
        }
        try {
            is.close();
        } catch (IOException e) {
            throw new EnhancerException("Cannot close the input stream for class '" + className + "'.", e);
        }

    }
    */

    /**
     * Override the super class method by using only the injection adapter.
     * @throws EnhancerException if the class can't be enhanced.
     */
    @Override
    public void enhance() throws EnhancerException {
        for (EjbJarClassMetadata classAnnotationMetadata : getEjbJarAnnotationMetadata()
                .getEjbJarClassMetadataCollection()) {
            ClassReader cr = getClassReader(classAnnotationMetadata);
            ClassWriter cw = new ClassWriter(ClassWriter.COMPUTE_MAXS);
            InjectionClassAdapter injectionClassAdapter = new InjectionClassAdapter(classAnnotationMetadata, cw,
                    getMap(), true);
            ClientLifeCycleAdapter clientLifeCycleAdapter = new ClientLifeCycleAdapter(classAnnotationMetadata,
                    injectionClassAdapter);
            cr.accept(clientLifeCycleAdapter, 0);

            ((EasyBeansClassLoader) getClassLoader()).addClassDefinition(classAnnotationMetadata.getClassName()
                    .replace("/", "."), cw.toByteArray());
        }
    }

}
