/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxAnnotationSecurityRolesAllowedVisitor.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer.visitors;

import java.util.ArrayList;
import java.util.List;

import org.ow2.easybeans.deployment.annotations.analyzer.AnnotationType;
import org.ow2.easybeans.deployment.metadata.interfaces.IAnnotationSecurityRolesAllowed;

/**
 * This class manages the handling of &#64;{@link javax.annotation.security.DeclareRoles}
 * annotation.
 * @param <T> An implementation of IAnnotationSecurityRolesAllowed interface.
 * @author Florent Benoit
 */
public class JavaxAnnotationSecurityRolesAllowedVisitor<T extends IAnnotationSecurityRolesAllowed> extends
        ObjectArrayAnnotationVisitor<T, String> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/security/RolesAllowed;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class/method metadata
     */
    public JavaxAnnotationSecurityRolesAllowedVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        List<String> rolesAllowed = new ArrayList<String>();
        for (String s : getArrayObjects()) {
            rolesAllowed.add(s);
        }
        getAnnotationMetadata().setRolesAllowed(rolesAllowed);
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
