/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxEjbApplicationExceptionVisitor.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz;

import javax.ejb.ApplicationException;

import org.ow2.easybeans.deployment.annotations.analyzer.AnnotationType;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.ObjectAnnotationVisitor;
import org.ow2.easybeans.deployment.annotations.impl.JApplicationException;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;

/**
 * This class manages the handling of the &#64;{@link javax.ejb.ApplicationException} annotation.<br>
 * @author Florent Benoit
 */
public class JavaxEjbApplicationExceptionVisitor extends ObjectAnnotationVisitor<EjbJarClassMetadata, Boolean> implements
        AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/ApplicationException;";

    /**
     * Constructor.
     * @param classAnnotationMetadata linked to a class metadata
     */
    public JavaxEjbApplicationExceptionVisitor(final EjbJarClassMetadata classAnnotationMetadata) {
        super(classAnnotationMetadata);
    }

    /**
     * Visits the end of the annotation. Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        Boolean b = getValue();

        ApplicationException jApplicationException;
        // no value --> default value
        if (b == null) {
            jApplicationException = new JApplicationException();
        } else {
            jApplicationException = new JApplicationException(b.booleanValue());
        }

        getAnnotationMetadata().setApplicationException(jApplicationException);

    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
