/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxPersistencePersistenceContextsVisitor.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz;

import java.util.ArrayList;
import java.util.List;

import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxPersistencePersistenceContextVisitor;
import org.ow2.easybeans.deployment.annotations.impl.JavaxPersistenceContext;
import org.ow2.easybeans.deployment.metadata.CommonClassMetadata;

/**
 * This class manages the handling of &#64;{@link javax.persistence.PersistenceContexts}
 * annotation.
 * @author Florent Benoit
 */
public class JavaxPersistencePersistenceContextsVisitor extends
        JavaxPersistencePersistenceContextVisitor<CommonClassMetadata<?, ?, ?>> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/persistence/PersistenceContexts;";

    /**
     * List of JavaxPersistenceContext object.
     */
    private List<JavaxPersistenceContext> javaxPersistenceContexts = null;

    /**
     * Object is added to the list.
     */
    private boolean isAdded = false;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxPersistencePersistenceContextsVisitor(final CommonClassMetadata<?, ?, ?> annotationMetadata) {
        super(annotationMetadata);
        javaxPersistenceContexts = new ArrayList<JavaxPersistenceContext>();
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.easybeans.asm.Type}.
     */
    @Override
    public void visit(final String name, final Object value) {
        // list not empty, need to create another reference
        // at the first item found
        if (javaxPersistenceContexts.size() > 0 && isAdded) {
            setJavaxPersistenceContext(new JavaxPersistenceContext());
            isAdded = false;
        }

        // do super code
        super.visit(name, value);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // add object in the list
        if (!isAdded) {
            javaxPersistenceContexts.add(getJavaxPersistenceContext());
            isAdded = true;
        }

        // update list
        getAnnotationMetadata().setJavaxPersistencePersistenceContexts(javaxPersistenceContexts);
    }

    /**
     * @return type of the annotation (its description)
     */
    @Override
    public String getType() {
        return TYPE;
    }

}
