/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JRemove.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.impl;

import java.lang.annotation.Annotation;

import javax.ejb.Remove;

/**
 * Acts as an implementation of &#64;{@link javax.ejb.Remove} annotation.
 * @author Florent Benoit
 */
public class JRemove implements Remove {

    /**
     * Don't remove object if there is an application exception.
     */
    private boolean retainIfException = false;

    /**
     * Build an object which represents&#64;{@link javax.ejb.Remove}.<br>
     * Default value for retainIfException is false.
     */
    public JRemove() {
        this(false);
    }

    /**
     * Build an object which represents&#64;{@link javax.ejb.Remove} with a
     * given boolean.
     * @param retainIfException true/false (false is a default value)
     */
    public JRemove(final boolean retainIfException) {
        this.retainIfException = retainIfException;
    }

    /**
     * @return the retainIfException value (true/false).
     */
    public boolean retainIfException() {
        return retainIfException;
    }

    /**
     * @return annotation type.
     */
    public Class<? extends Annotation> annotationType() {
        return Remove.class;
    }

    /**
     * @return string representation.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        // retainIfException
        sb.append("[retainIfException=");
        sb.append(retainIfException);

        sb.append("]");
        return sb.toString();
    }
}
