/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ENCBinding.java 2054 2007-11-20 14:43:55Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.enc;

import org.ow2.easybeans.deployment.api.IBinding;

/**
 * JNDI Binding used in ENC for a given type (like persistence context, ejb,
 * etc.).
 * @param <T> the given type
 * @author Florent BENOIT
 */
public class ENCBinding<T> implements IBinding<T> {

    /**
     * Name of the binding.
     */
    private String name = null;

    /**
     * Value of the binding.
     */
    private T value = null;

    /**
     * Build the given ENC binding.
     * @param name the given name.
     * @param value the given value.
     */
    public ENCBinding(final String name, final T value) {
        this.name = name;
        this.value = value;
    }

    /**
     * @return the name used for the ENC.
     */
    public String getName() {
        return name;
    }

    /**
     * @return the object associated to the ENC name.
     */
    public T getValue() {
        return value;
    }
}
