/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonFieldMetadata.java 2833 2008-04-11 08:09:39Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.metadata;

import org.ow2.easybeans.deployment.annotations.impl.JAnnotationResource;
import org.ow2.easybeans.deployment.annotations.impl.JEjbEJB;
import org.ow2.easybeans.deployment.annotations.impl.JavaxPersistenceContext;
import org.ow2.easybeans.deployment.annotations.impl.JavaxPersistenceUnit;
import org.ow2.easybeans.deployment.metadata.interfaces.ISharedMetadata;
import org.ow2.util.scan.api.metadata.FieldMetadata;
import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * EZB common field metadata.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonFieldMetadata<
    C extends CommonClassMetadata<C, M, F>,
    M extends CommonMethodMetadata<C, M, F>,
    F extends CommonFieldMetadata<C, M, F>>
        extends FieldMetadata<C, M, F> implements ISharedMetadata {

    /**
     * metadata common with class, field and method.
     */
    private CommonMetadata ejbJarCommonMetadata;

    /**
     * Constructor.
     * @param jField signature
     * @param classAnnotationMetadata parent
     */
    public CommonFieldMetadata(final JField jField, final C classAnnotationMetadata) {
        super(jField, classAnnotationMetadata);
        this.ejbJarCommonMetadata = new CommonMetadata();
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final JEjbEJB getJEjbEJB() {
        return this.ejbJarCommonMetadata.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final JEjbEJB jEjbEJB) {
        this.ejbJarCommonMetadata.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final JAnnotationResource getJAnnotationResource() {
        return this.ejbJarCommonMetadata.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final JAnnotationResource jAnnotationResource) {
        this.ejbJarCommonMetadata.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.ejbJarCommonMetadata.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final JavaxPersistenceContext getJavaxPersistenceContext() {
        return this.ejbJarCommonMetadata.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final JavaxPersistenceContext javaxPersistenceContext) {
        this.ejbJarCommonMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.ejbJarCommonMetadata.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final JavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.ejbJarCommonMetadata.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final JavaxPersistenceUnit javaxPersistenceUnit) {
        this.ejbJarCommonMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

}
