/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EjbJarFieldMetadata.java 2833 2008-04-11 08:09:39Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.metadata.ejbjar;

import org.ow2.easybeans.deployment.metadata.CommonFieldMetadata;
import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * This class represents the annotation metadata of a field.
 * @author Florent Benoit
 */
public class EjbJarFieldMetadata
extends CommonFieldMetadata<EjbJarClassMetadata, EjbJarMethodMetadata, EjbJarFieldMetadata> {

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(FieldAnnotationMetadata.class);

    /**
     * Constructor.
     * @param jField the field on which we will set/add metadata
     * @param classAnnotationMetadata the parent metadata.
     */
    public EjbJarFieldMetadata(final JField jField, final EjbJarClassMetadata classAnnotationMetadata) {
        super(jField, classAnnotationMetadata);
    }

    /**
     * @return name of the field
     */
    public String getFieldName() {
        return getJField().getName();
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        String titleIndent = " ";
        String indent = "   ";
        // classname
        sb.append(titleIndent);
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[\n");

        // Add super class toString()
        sb.append(super.toString());

        // Field
        sb.append(indent);
        sb.append("jField=");
        sb.append(getJField());
        sb.append("\n");

        // inherited
        if (isInherited()) {
            sb.append(indent);
            sb.append("inherited=true");
            sb.append("\n");
        }

        sb.append(titleIndent);
        sb.append("]\n");
        return sb.toString();
    }

}
